<?php

return [
    'Names' => [
        'ADP' => [
            'ADP',
            'ເປເຊຕາ ອັນໂດລາ',
        ],
        'AED' => [
            'AED',
            'ສະ​ຫະ​ລັດ​ອາ​ຣັບ​ອາ​ມິ​ເຣດ ເດີ​ແຮມ',
        ],
        'AFA' => [
            'AFA',
            'ອັບການິ ອັບການິສະຖານ (1927–2002)',
        ],
        'AFN' => [
            'AFN',
            'ອັຟ​ກັນ ອັຟ​ກາ​ນິ',
        ],
        'ALL' => [
            'ALL',
            'ອັລ​ບາ​ນຽນ ເລກ',
        ],
        'AMD' => [
            'AMD',
            'ອາ​ເມ​ນຽນ ແດຣມ',
        ],
        'ANG' => [
            'ANG',
            'ເນ​ເທີ​ແລນ ແອນ​ຕິ​ລຽນ ກິວ​ເດີ',
        ],
        'AOA' => [
            'AOA',
            'ແອງ​ໂກ​ລັນ ຄວນ​ຊາ',
        ],
        'AOK' => [
            'AOK',
            'ກວານຊາ ແອງໂກລາ (1977–1991)',
        ],
        'AON' => [
            'AON',
            'ກວານຊາ ແອງໂກລາ ໃໝ່ (1995–1999)',
        ],
        'AOR' => [
            'AOR',
            'ກວານຊາກທີ່ແກ້ໄຂໃໝ່ ແອງກູລາ (1995–1999)',
        ],
        'ARA' => [
            'ARA',
            'ອອສຕຣານ ອາກຊັງຕິນ',
        ],
        'ARL' => [
            'ARL',
            'ເປໂຊເລ ອາກຊັງຕິນ (1970–1983)',
        ],
        'ARM' => [
            'ARM',
            'ເປໂຊ ອາກຊັງຕິນ (1881–1970)',
        ],
        'ARP' => [
            'ARP',
            'ເປໂຊ ອາກຊັງຕິນ (1983–1985)',
        ],
        'ARS' => [
            'ARS',
            'ອາ​ເຈນ​ທິ​ນາ ເປ​ໂຊ',
        ],
        'ATS' => [
            'ATS',
            'ຊິລລິງ ອົດສະຕາລີ',
        ],
        'AUD' => [
            'A$',
            'ອອສ​ເຕຣ​ລຽນ ໂດ​ລ່າ',
        ],
        'AWG' => [
            'AWG',
            'ອະຣູແບນ ຟລໍຣິນ',
        ],
        'AZM' => [
            'AZM',
            'ມານັດ ອາແຊກບາຍຊານ (1993–2006)',
        ],
        'AZN' => [
            'AZN',
            'ອາ​ເຊີ​ໄບ​ຈາ​ນິ ມາ​ນັດ',
        ],
        'BAD' => [
            'BAD',
            'ດີນາ ບອສເນຍ ເຮີເຊໂບວາເນຍ (1992–1994)',
        ],
        'BAM' => [
            'BAM',
            'ບອ​ສ​ເນຍ-ເຮີ​ເຊ​ໂກວິ​ນາ ຄອນ​ເວີດ​ຕິ​ໂບ ມາກ',
        ],
        'BAN' => [
            'BAN',
            'ດີນາໃໝ່ ບອສເນຍ ເຮີເຊໂບວີນາ(1994–1997)',
        ],
        'BBD' => [
            'BBD',
            'ໂດລ່າ ບາບາດຽນ',
        ],
        'BDT' => [
            'BDT',
            'ບັງ​ຄລາ​ເທດ ຕາ​ກາ',
        ],
        'BEC' => [
            'BEC',
            'ຟຣັງ ບູນກາລີ (ປ່ຽນແປງໄດ້)',
        ],
        'BEF' => [
            'BEF',
            'ຟຣັງ ບູນກາລີ',
        ],
        'BEL' => [
            'BEL',
            'ຟຣັງ ບູນກາລີ (ການເງິນ)',
        ],
        'BGL' => [
            'BGL',
            'ຮາດເລບ ບູນກາລີ',
        ],
        'BGM' => [
            'BGM',
            'ເລບ ສັງຄົມບູນກາລີ',
        ],
        'BGN' => [
            'BGN',
            'ບັງ​ກາ​ຣຽນ ເລບ',
        ],
        'BGO' => [
            'BGO',
            'ເລບ ບູນກາລີ (1879–1952)',
        ],
        'BHD' => [
            'BHD',
            'ບາ​ໄຣ​ນິ ດິ​ນາ',
        ],
        'BIF' => [
            'BIF',
            'ບຸ​ຣັນ​ດຽນ ຟຣັງ',
        ],
        'BMD' => [
            'BMD',
            'ໂດ​ລ່າ​ເບີ​ມິວ​ດາ',
        ],
        'BND' => [
            'BND',
            'ບຣູ​ໄນ ໂດ​ລ່າ',
        ],
        'BOB' => [
            'BOB',
            'ໂບ​ລິ​ວຽນ ໂບ​ລິ​ເວຍ​ໂນ',
        ],
        'BOL' => [
            'BOL',
            'ໂລລິເວຍໂນ ໂລລິເວຍ (1863–1963)',
        ],
        'BOP' => [
            'BOP',
            'ເປໂຊໂລລິເວຍ',
        ],
        'BOV' => [
            'BOV',
            'ມະດອນ ໂລລິເວຍ',
        ],
        'BRB' => [
            'BRB',
            'ກຣູເຊໂດບາຊິ ໃໝ່ (1967–1986)',
        ],
        'BRC' => [
            'BRC',
            'ກຣູຊາໂດບາຊິວ (1986–1989)',
        ],
        'BRE' => [
            'BRE',
            'ກຣູເຊໂຣ ບາຊິ ກຣູໂຊ ບາຊິວ (1993–1994)',
        ],
        'BRL' => [
            'R$',
            'ບຣາ​ຊິ​ລຽນ ຣຽວ',
        ],
        'BRN' => [
            'BRN',
            'ກຣູຊາໂດ ບາຊິວ ໃໝ່ (1989–1990)',
        ],
        'BRR' => [
            'BRR',
            'ກຣູເຊໂຣ ບາຊິວ (1993–1994)',
        ],
        'BRZ' => [
            'BRZ',
            'ກຣູເຊໂຣ ບາຊິວ (1942–1967)',
        ],
        'BSD' => [
            'BSD',
            'ໂດລ່າ ບາຮາມຽນ',
        ],
        'BTN' => [
            'BTN',
            'ພູ​ຖານ ງຸນດຣັມ',
        ],
        'BUK' => [
            'BUK',
            'ຈາດ ພະມ້າ',
        ],
        'BWP' => [
            'BWP',
            'ບອດ​ສະ​ວາ​ນານ ພູ​ລາ',
        ],
        'BYB' => [
            'BYB',
            'ຣູໂບ ເບຣາຣຸສ ໃໝ່(1994–1999)',
        ],
        'BYN' => [
            'BYN',
            'ເບ​ລາ​ຣຸ​ສ​ຊຽນ ຣູ​ເບິນ',
        ],
        'BYR' => [
            'BYR',
            'ເບ​ລາ​ຣຸ​ສ​ຊຽນ ຣູ​ເບິນ (2000–2016)',
        ],
        'BZD' => [
            'BZD',
            'ໂດ​ລ່າ​ເບ​ລີຊ',
        ],
        'CAD' => [
            'CA$',
            'ໂດລ່າແຄນາດາ',
        ],
        'CDF' => [
            'CDF',
            'ຄອງ​ໂກ​ລີສ ຟຣັງ',
        ],
        'CHE' => [
            'CHE',
            'ເອີໂຣ WIR',
        ],
        'CHF' => [
            'CHF',
            'ສະ​ວິ​ສ ຟ​ຣັງ',
        ],
        'CHW' => [
            'CHW',
            'ຟຣັງ WIR',
        ],
        'CLE' => [
            'CLE',
            'ເອສກູໂດ ຊິລີ',
        ],
        'CLF' => [
            'CLF',
            'ຫົວໜ່ວຍບັນຊີ (UF) ຊິລີ',
        ],
        'CLP' => [
            'CLP',
            'ຊິ​ລຽນ ເປ​ໂຊ',
        ],
        'CNH' => [
            'CNH',
            'ຢວນຈີນ (ນອກປະເທດ)',
        ],
        'CNY' => [
            'CN¥',
            'ຈີນ ຢວນ',
        ],
        'COP' => [
            'COP',
            'ໂຄ​ລົມ​ບຽນ ເປ​ໂຊ',
        ],
        'COU' => [
            'COU',
            'ຫົວໜ່ວຍຄ່າຈິງ ໂຄລັມເບຍ',
        ],
        'CRC' => [
            'CRC',
            'ໂຄສຕາ ຣິກັນ ໂຄລອນ',
        ],
        'CSD' => [
            'CSD',
            'ດີນາ ເຊີເບຍ (2002–2006)',
        ],
        'CSK' => [
            'CSK',
            'ຮາດໂກຣູນາ ເຊັກໂກສະໂລວັກ',
        ],
        'CUC' => [
            'CUC',
            'ຄິວແບນ ຄອນເວີດຕິໂບ ເປໂຊ',
        ],
        'CUP' => [
            'CUP',
            'ຄິວແບນ ເປໂຊ',
        ],
        'CVE' => [
            'CVE',
            'ເຄບ ເວີດ​ດີນ ເອ​ສ​ຄູ​ໂດ',
        ],
        'CYP' => [
            'CYP',
            'ປອນ ໄຊປຣັດ',
        ],
        'CZK' => [
            'CZK',
            'ເຊກ ໂຄ​ຣູ​ນາ',
        ],
        'DDM' => [
            'DDM',
            'ມາກ ເຢຍລະມັນ ຕາເວັນອອກ',
        ],
        'DEM' => [
            'DEM',
            'ມາກ ເຢຍລະມັນ',
        ],
        'DJF' => [
            'DJF',
            '​ດິ​ບູ​ຈຽນ ຟຣັງ',
        ],
        'DKK' => [
            'DKK',
            'ແດນ​ນິ​ຊ ໂຄຣນ',
        ],
        'DOP' => [
            'DOP',
            'ໂດ​ມິ​ນິ​ກັນ ເປ​ໂຊ',
        ],
        'DZD' => [
            'DZD',
            'ອັລ​ເຈີ​ຣຽນ ດິ​ນາ',
        ],
        'ECS' => [
            'ECS',
            'ຊູເກ ເອກາວາດໍ',
        ],
        'ECV' => [
            'ECV',
            'ຫົວໜ່ວຍຄ່າຄົງທີ່ຂອງເອກາວາດໍ',
        ],
        'EEK' => [
            'EEK',
            'ຄຣູນເອສ ໂຕເນຍ',
        ],
        'EGP' => [
            'EGP',
            'ອີ​ຢິບ​ທຽນ ພາວດ໌',
        ],
        'ERN' => [
            'ERN',
            'ອິ​ຣິ​ທຣຽນ ແນກ​ຟ​າ',
        ],
        'ESA' => [
            'ESA',
            'ເປເຊຕາສະເປັນ (ບັນຊີ)',
        ],
        'ESB' => [
            'ESB',
            'ເປເຊຕາສະເປນ (ປ່ຽນແປງໄດ້)',
        ],
        'ESP' => [
            'ESP',
            'ເປເຊຕາ ສະເປນ',
        ],
        'ETB' => [
            'ETB',
            'ເອ​ທິ​ໂອ​ປຽນ ເບີ​ຣ໌',
        ],
        'EUR' => [
            '€',
            'ຢູ​ໂຣ',
        ],
        'FIM' => [
            'FIM',
            'ມາກກາ ຟິນແລນ',
        ],
        'FJD' => [
            'FJD',
            'ຟິ​ຈຽນ ໂດ​ລ່າ',
        ],
        'FKP' => [
            'FKP',
            'ຟອ​ລ໌ກ​ແລນ ໄອ​ແລນ​ສ໌ ພາວ​ດ໌',
        ],
        'FRF' => [
            'FRF',
            'ຟຣັງ ຝຣັ່ງ',
        ],
        'GBP' => [
            '£',
            'ອັງກິດ ປອນ',
        ],
        'GEK' => [
            'GEK',
            'ກູປອນ ລາຣິທ ຈໍເຈຍ',
        ],
        'GEL' => [
            'GEL',
            'ຈໍ​ຈຽນ ລາ​ຣິ',
        ],
        'GHC' => [
            'GHC',
            'ເຊດີ ການາ (1979–2007)',
        ],
        'GHS' => [
            'GHS',
            'ກາ​ນາ​ອຽນ ເຊ​ດິ',
        ],
        'GIP' => [
            'GIP',
            'ກິບ​ຣາ​ທາ ພາ​ວດ໌',
        ],
        'GMD' => [
            'GMD',
            '​ແກມ​ບຽນ ດາ​ລາ​ຊິ',
        ],
        'GNF' => [
            'GNF',
            'ກິ​ນຽນ ຟຣັງ',
        ],
        'GNS' => [
            'GNS',
            'ໄຊລິ ກີນີ',
        ],
        'GQE' => [
            'GQE',
            'ເອັກເວເລ ອີຄວາຕິຣຽວ ກິນີ',
        ],
        'GRD' => [
            'GRD',
            'ດາກຊະມາ ເກຣັກ',
        ],
        'GTQ' => [
            'GTQ',
            'ກົວເຕມາລານ ເຄັດຊອນ',
        ],
        'GWE' => [
            'GWE',
            'ເອສກູໂດ ກີນີໂປຕູເກດ',
        ],
        'GWP' => [
            'GWP',
            'ເປໂຊກິນີ-ບິສເຊົາ',
        ],
        'GYD' => [
            'GYD',
            'ກາຍ​ຢາ​ນີ​ສ ໂດ​ລ່າ',
        ],
        'HKD' => [
            'HK$',
            'ຮອງ​ກົງ ໂດ​ລ່າ',
        ],
        'HNL' => [
            'HNL',
            'ຮອນດູແຣນ ເລມພິຣາ',
        ],
        'HRD' => [
            'HRD',
            'ດີນາ ໂຄຣເອເຊຍ',
        ],
        'HRK' => [
            'HRK',
            'ໂຄຣ​ເອ​ທຽນ ຄູ​ນາ',
        ],
        'HTG' => [
            'HTG',
            'ໄຮ​ຕຽນ ກົວ​ເດ',
        ],
        'HUF' => [
            'HUF',
            'ຮັງ​ກາ​ຣຽນ ຟໍ​ຣິນ',
        ],
        'IDR' => [
            'IDR',
            'ອິນ​ໂດ​ເນ​ຊຽນ ໂດ​ລ່າ',
        ],
        'IEP' => [
            'IEP',
            'ປອນ ໄອຣິຊ',
        ],
        'ILP' => [
            'ILP',
            'ປອນ ອີສະລາເອວ',
        ],
        'ILS' => [
            '₪',
            'ອິສ​ຣາ​ເອວ​ລິ ນິວ ເຊ​ເກວ',
        ],
        'INR' => [
            '₹',
            'ອິນ​ເດຍ ຣູ​ປີ',
        ],
        'IQD' => [
            'IQD',
            'ອິ​ຣັກ​ກິ ດິ​ນາ',
        ],
        'IRR' => [
            'IRR',
            'ອິ​ຣາ​ນິ ຣຽວ',
        ],
        'ISK' => [
            'ISK',
            'ໄອ​ສ໌​ແລນ​ດິກ ໂຄຣ​ນາ',
        ],
        'ITL' => [
            'ITL',
            'ລິຣາ ອີຕາລີ',
        ],
        'JMD' => [
            'JMD',
            '​ຈາ​ໄມ​ກັນ ໂດ​ລ່າ',
        ],
        'JOD' => [
            'JOD',
            'ຈໍ​ແດ​ນຽນ ດິ​ນາ',
        ],
        'JPY' => [
            'JP¥',
            'ຍີ່​ປຸ່ນ ເຢນ',
        ],
        'KES' => [
            'KES',
            'ເຄນ​ຢັນ ຊິວ​ລິງ',
        ],
        'KGS' => [
            'KGS',
            'ຄ​ຣີ​ກິສ​​ຖາ​ນິ ໂຊມ',
        ],
        'KHR' => [
            'KHR',
            'ກຳ​ປູ​ເຈຍ ຣຽວ',
        ],
        'KMF' => [
            'KMF',
            'ໂຄ​ໂມ​ຣຽນ ຟຣັງ',
        ],
        'KPW' => [
            'KPW',
            'ເກົາ​ຫລີ​ເໜືອ ວອນ',
        ],
        'KRH' => [
            'KRH',
            'ຮາວານ ເກົາຫຼີເນື້',
        ],
        'KRO' => [
            'KRO',
            'ວອນ ເກົາຫຼີໃຕ້ (1945–1953)',
        ],
        'KRW' => [
            '₩',
            'ເກົາ​ຫລີໃຕ້ ວອນ',
        ],
        'KWD' => [
            'KWD',
            'ຄູ​ເວ​ຕິ ດິ​ນາ',
        ],
        'KYD' => [
            'KYD',
            'ເຄ​ແມນ ໄອ​ແລນ ໂດ​ລ່າ',
        ],
        'KZT' => [
            'KZT',
            'ຄາ​ຊັກ​ສະ​ຖາ​ນິ ເຕັງ​ເຈ',
        ],
        'LAK' => [
            '₭',
            'ລາວ ກີບ',
        ],
        'LBP' => [
            'LBP',
            'ເລ​ບາ​ນີ​ສ ພາວດ໌',
        ],
        'LKR' => [
            'LKR',
            'ສີ​ລັງ​ກາ ຣູ​ປີ',
        ],
        'LRD' => [
            'LRD',
            'ລິ​ເບີ​ຣຽນ ໂດ​ລ່າ',
        ],
        'LSL' => [
            'LSL',
            'ໂລຕິ ເລໂຊໂຕ',
        ],
        'LTL' => [
            'LTL',
            'ລິ​ທົວ​ນຽນ ລິ​ທັ​ສ',
        ],
        'LTT' => [
            'LTT',
            'ທາໂລນັສ ລິທົວເນຍ',
        ],
        'LUC' => [
            'LUC',
            'ຟຣັງ ລຸກຊຳບວກ ທີ່ປ່ຽນແປງ',
        ],
        'LUF' => [
            'LUF',
            'ຟຣັງ ລຸກຊຳບວກ',
        ],
        'LUL' => [
            'LUL',
            'ຟຣັງ ລຸກຊຳບວກ ການເງິນ',
        ],
        'LVL' => [
            'LVL',
            'ລັດ​ວຽນ ລັດ​ສ໌',
        ],
        'LVR' => [
            'LVR',
            'ຣູໂບ ລາວຽນ',
        ],
        'LYD' => [
            'LYD',
            'ລິບ​ບຽນ ດິ​ນາ',
        ],
        'MAD' => [
            'MAD',
            'ມໍ​ຣັອກ​ແຄນ​ ເດີ​ແຮມ',
        ],
        'MAF' => [
            'MAF',
            'ຟຣັງ ໂມຣອກໂກ',
        ],
        'MCF' => [
            'MCF',
            'ຟຣັງ ໂມດາໂກ',
        ],
        'MDC' => [
            'MDC',
            'ບັດປັນສ່ວນ ມອງໂດວາ',
        ],
        'MDL' => [
            'MDL',
            'ມອນ​ໂດ​ແວນ ເລ​ອູ',
        ],
        'MGA' => [
            'MGA',
            'ມາ​ລາ​ກາ​ຊີ ອາ​ເຣຍ​ຣີ',
        ],
        'MGF' => [
            'MGF',
            'ຟຣັງ ມາດາກັດສະກາ',
        ],
        'MKD' => [
            'MKD',
            'ແມັກ​ເຊ​ໂດ​ນຽນ ເດ​ນາ',
        ],
        'MKN' => [
            'MKN',
            'ດີນາ ມາຊີໂດເນຍ (1992–1993)',
        ],
        'MLF' => [
            'MLF',
            'ຟຣັງ ມາລີ',
        ],
        'MMK' => [
            'MMK',
            'ມຽນ​ມາ ຈ໊າດ',
        ],
        'MNT' => [
            'MNT',
            'ມອງ​ໂກ​ລຽນ ຕູກຣິກ',
        ],
        'MOP' => [
            'MOP',
            'ມາ​ເກົ້າ ປາ​​ຕາ​ກາ',
        ],
        'MRO' => [
            'MRO',
            'ມົວ​ຣິ​ທາ​ນຽນ ອູ​ກິວ​ຢາ (1973–2017)',
        ],
        'MRU' => [
            'MRU',
            'ມົວ​ຣິ​ທາ​ນຽນ ອູ​ກິວ​ຢາ',
        ],
        'MTL' => [
            'MTL',
            'ລິຣາ ມອນຕາ',
        ],
        'MTP' => [
            'MTP',
            'ປອນ ມອນຕາ',
        ],
        'MUR' => [
            'MUR',
            'ເມົາ​ຣິ​ທຽນ ຣູ​ປີ',
        ],
        'MVR' => [
            'MVR',
            'ມັ​ລ​ດິ​ວຽນ ຣູ​ຟິ​ຢາ',
        ],
        'MWK' => [
            'MWK',
            'ມາ​ລາ​ວຽນ ຄວາ​ຊາ',
        ],
        'MXN' => [
            'MX$',
            'ເມັກຊິກັນ ເປໂຊ',
        ],
        'MXP' => [
            'MXP',
            'ຫົວໜ່ວຍເງິນ ເປໂຊ ແມັກຊິໂກ(1861–1992)',
        ],
        'MXV' => [
            'MXV',
            'ຫົວໜ່ວຍການລົງທຶນ ແມັກຊິໂກ',
        ],
        'MYR' => [
            'MYR',
            'ມາ​ເລ​ເຊຍ ຣິງ​ກິດ',
        ],
        'MZE' => [
            'MZE',
            'ເອສກູໂດ ໂມຊຳບິກ',
        ],
        'MZM' => [
            'MZM',
            'ເມຕິຄໍ ໂມຊຳບິກ (1980–2006)',
        ],
        'MZN' => [
            'MZN',
            'ໂມ​ແຊມ​ບິ​ກັນ ເມ​ທິ​ຄອນ',
        ],
        'NAD' => [
            'NAD',
            'ນາ​ມິ​ບຽນ ໂດ​ລ່າ',
        ],
        'NGN' => [
            'NGN',
            'ໄນ​ຣາ ​ໄນເຈີ​ຣຽນ',
        ],
        'NIC' => [
            'NIC',
            'ຄໍໂດບາ ນິກາຣາກົວ (1988–1991)',
        ],
        'NIO' => [
            'NIO',
            'ນິກາຣາກວນ ໂຄໂດບາ',
        ],
        'NLG' => [
            'NLG',
            'ກິລເດີ ເນເທີແລນ',
        ],
        'NOK' => [
            'NOK',
            'ນໍ​ເວ​ຈຽນ ​ໂຄຣນ',
        ],
        'NPR' => [
            'NPR',
            'ເນ​ປານ ຣູ​ປີ',
        ],
        'NZD' => [
            'NZ$',
            'ນິວ​ຊີ​ແລນ ໂດ​ລ່າ',
        ],
        'OMR' => [
            'OMR',
            'ໂອ​ມາ​ນິ ຣຽວ',
        ],
        'PAB' => [
            'PAB',
            'ພານາມານຽນ ບອນບົວ',
        ],
        'PEI' => [
            'PEI',
            'ອິນຕິ ເປຣູ',
        ],
        'PEN' => [
            'PEN',
            'ເປ​ຣູ​ວຽນ ໂຊ​ລ໌',
        ],
        'PES' => [
            'PES',
            'ໂຊນ ເປຣູ (1863–1965)',
        ],
        'PGK' => [
            'PGK',
            'ປາ​ປົວ ນິວ ກິ​ນຽນ ກິ​ນາ',
        ],
        'PHP' => [
            'PHP',
            'ຟິ​ລິບ​ປິນ ເປ​ໂຊ',
        ],
        'PKR' => [
            'PKR',
            'ປາ​ກິ​ສຖານ ຣູ​ປີ',
        ],
        'PLN' => [
            'PLN',
            'ໂປ​ລິ​ຊ ຊະ​ລໍ​ຕີ',
        ],
        'PLZ' => [
            'PLZ',
            'ຊະລອສຕີ ໂປແລນ (1950–1995)',
        ],
        'PTE' => [
            'PTE',
            'ເອສກູໂດ ໂປຕູເກສ',
        ],
        'PYG' => [
            'PYG',
            'ກວາຣານີ ປາຣາກວາຍ',
        ],
        'QAR' => [
            'QAR',
            'ຄາ​ຕາ​ຣິ ຣຽວ',
        ],
        'RHD' => [
            'RHD',
            'ດອນລາ ໂຣດີເຊຍ',
        ],
        'ROL' => [
            'ROL',
            'ລິວ ໂຣມາເນຍເກົ່າ',
        ],
        'RON' => [
            'RON',
            'ໂຣ​ມາ​ນຽນ ເລ​ອູ',
        ],
        'RSD' => [
            'RSD',
            'ເຊີ​ບຽນ ດິ​ນາ',
        ],
        'RUB' => [
            'RUB',
            'ຣັສ​ຊຽນ ຣູ​ເບິນ',
        ],
        'RUR' => [
            'RUR',
            'ຣູໂບ ຣັດເຊຍ (1991–1998)',
        ],
        'RWF' => [
            'RWF',
            'ຣະ​ວັນ​ດັນ ຟຣັງ',
        ],
        'SAR' => [
            'SAR',
            'ຊາ​ອູ​ດິ ຣິ​ຢອນ',
        ],
        'SBD' => [
            'SBD',
            'ໂຊ​ໂລມອນ ໄອ​ແລນ ໂດ​ລ່າ',
        ],
        'SCR' => [
            'SCR',
            'ເຊ​ເຊວ​ລອຍ​ສ໌ ຣູ​ປີ',
        ],
        'SDD' => [
            'SDD',
            'ດີນາ ຊູດານເກົ່າ',
        ],
        'SDG' => [
            'SDG',
            'ຊູ​ດານ​ນີ​ສ ພາວດ໌',
        ],
        'SDP' => [
            'SDP',
            'ປອນ ຊູດານເກົ່າ',
        ],
        'SEK' => [
            'SEK',
            'ສະ​ວີ​ດິ​ຊ ໂຄຣ​ນາ',
        ],
        'SGD' => [
            'SGD',
            'ສິງ​ກະ​ໂປ ໂດ​ລ່າ',
        ],
        'SHP' => [
            'SHP',
            'ເຊນ ເຮ​ເລ​ນາ ພາວດ໌',
        ],
        'SIT' => [
            'SIT',
            'ໂຕລາ ສະໂລວິເນຍ',
        ],
        'SKK' => [
            'SKK',
            'ຄູໂຣນາ ສະໂລວັກ',
        ],
        'SLE' => [
            'SLE',
            'ເຊຍ​ນາ ​ເລໂອ​ນຽນ ເລ​ໂອນ',
        ],
        'SLL' => [
            'SLL',
            'ເຊຍ​ນາ ​ເລໂອ​ນຽນ ເລ​ໂອນ (1964—2022)',
        ],
        'SOS' => [
            'SOS',
            'ໂຊ​ມາ​ລິ ຊິວ​ລິງ',
        ],
        'SRD' => [
            'SRD',
            'ຊູ​ຣິ​ນາ​ມີ​ສ ໂດ​ລ່າ',
        ],
        'SRG' => [
            'SRG',
            'ກິລເດີ ຊູຣິນາເມ',
        ],
        'SSP' => [
            'SSP',
            'ເຊົາ​ທ໌ ຊູ​ດານ​ນີ​ສ ພາວດ໌',
        ],
        'STD' => [
            'STD',
            'ເຊົາ ໂທ​ເມ ແອນ ພ​ຣິນ​ຊິ​ປີ ໂດບຣາ (1977–2017)',
        ],
        'STN' => [
            'STN',
            'ເຊົາ ໂທ​ເມ ແອນ ພ​ຣິນ​ຊິ​ປີ ໂດບຣາ',
        ],
        'SUR' => [
            'SUR',
            'ຣູໂບ ໂຊວຽດ',
        ],
        'SVC' => [
            'SVC',
            'ໂກລອງ ເອກາວາດໍ',
        ],
        'SYP' => [
            'SYP',
            'ຊີ​ຣຽນ ພາວດ໌',
        ],
        'SZL' => [
            'SZL',
            'ສະ​ວາ​ຊິ ລິ​ລັນ​ກິ​ນີ',
        ],
        'THB' => [
            '฿',
            'ໄທ ບາດ',
        ],
        'TJR' => [
            'TJR',
            'ຣູໂບ ຕັຈີກິສຖານ',
        ],
        'TJS' => [
            'TJS',
            'ທາ​ຈິ​ກິ​​ຖາ​ນິ ໂຊ​ໂມ​ນິ',
        ],
        'TMM' => [
            'TMM',
            'ມານັດ ຕວກເມນິສຖານ (1966–1987)',
        ],
        'TMT' => [
            'TMT',
            'ເຕີກ​ເມ​ນິ​ສ​ຖາ​ນິ ມາ​ນັດ',
        ],
        'TND' => [
            'TND',
            'ຕູ​ນິ​ຊຽນ ດິ​ນາ',
        ],
        'TOP' => [
            'TOP',
            'ຕອງ​ກັນ ປາ​ອັງ​ກາ',
        ],
        'TPE' => [
            'TPE',
            'ເອສກູໂດ ຕີມໍ',
        ],
        'TRL' => [
            'TRL',
            'ລີຕາ ຕູຣາກີເກົ່າ',
        ],
        'TRY' => [
            'TRY',
            'ເຕີ​ກິ​ຊ ລິ​ຣາ',
        ],
        'TTD' => [
            'TTD',
            'ທ​ຣິ​ນິ​ແດດ & ໂທ​ບາ​ໂກ ໂດ​ລ່າ',
        ],
        'TWD' => [
            'NT$',
            'ນິວ ໄຕ້​ຫວັນ ໂດ​ລ່າ',
        ],
        'TZS' => [
            'TZS',
            'ທານ​ຊາ​ນຽນ ຊິວ​ລິງ',
        ],
        'UAH' => [
            'UAH',
            'ຢູ​ເຄຣ​ນຽນ ຮະ​ຣີບ​ເນຍ',
        ],
        'UAK' => [
            'UAK',
            'ຄາໂບວາເນດ ອູແກຣນ',
        ],
        'UGS' => [
            'UGS',
            'ຊິນລິງ ອູກັນດາ (1966–1987)',
        ],
        'UGX' => [
            'UGX',
            'ອູ​ກັນ​ດັນ ຊິວ​ລິງ',
        ],
        'USD' => [
            'US$',
            '​ໂດ​ລ່າ​ສະ​ຫະ​ລັດຯ',
        ],
        'USN' => [
            'USN',
            'ດອນລາສະຫະລັດ (ມື້ຖັດໄປ)',
        ],
        'USS' => [
            'USS',
            'ດອນລາສະຫະລັດ (ມື້ດຽວກັນ)',
        ],
        'UYI' => [
            'UYI',
            'ເປໂຊອູຣຸກວຍ (ຫົວໜ່ວຍອິນເດັກ)',
        ],
        'UYP' => [
            'UYP',
            'ເປໂຊ ອູຣຸກວຍ (1975–1993)',
        ],
        'UYU' => [
            'UYU',
            'ອູ​ຣຸ​ກົວ​ຢານ ເປ​ໂຊ',
        ],
        'UZS' => [
            'UZS',
            'ອຸສເບກິສຖານິ ໂຊມ',
        ],
        'VEB' => [
            'VEB',
            'ໂບລີວາ ເວເນຊູເອລາ (1871–2008)',
        ],
        'VEF' => [
            'VEF',
            'ເວ​ເນ​ຊູ​ເອ​ລັນ ໂບ​ລິ​ວາ (2008–2018)',
        ],
        'VES' => [
            'VES',
            'ເວ​ເນ​ຊູ​ເອ​ລັນ ໂບ​ລິ​ວາ',
        ],
        'VND' => [
            '₫',
            'ຫວຽດ​ນາມ ດົງ',
        ],
        'VNN' => [
            'VNN',
            'ດົງ ຫວຽດນາມ (1978–1985)',
        ],
        'VUV' => [
            'VUV',
            '​ວາ​ນົວ​ຕູ ວາ​ຕູ',
        ],
        'WST' => [
            'WST',
            'ຊາ​ໂມນ ທາ​ລາ',
        ],
        'XAF' => [
            'FCFA',
            'ສາທາລະນະລັດອາຟຣິກາກາງ',
        ],
        'XCD' => [
            'EC$',
            'ອີ​ສ ຄາ​ຣິ​ບຽນ ໂດ​ລ່າ',
        ],
        'XCG' => [
            'Cg.',
            'ຄາຣິບຽນ ກິວເດີ',
        ],
        'XEU' => [
            'XEU',
            'ຫົວໜ່ວຍສະກຸນເງິນ ເອີຣົບ',
        ],
        'XFO' => [
            'XFO',
            'ຟຣັງ ຄຳຝຣັ່ງ',
        ],
        'XFU' => [
            'XFU',
            'ຟຣັງ ຢູໄອຊີ ຝຣັ່ງ',
        ],
        'XOF' => [
            'F CFA',
            'ຟັງເຊຟານ ອາຟຣິກາຕາເວັນຕົກ',
        ],
        'XPF' => [
            'CFPF',
            'ຊີ​ເອັບ​ພີ ຟຣັງ',
        ],
        'XRE' => [
            'XRE',
            'ກອງທຶນໄຣເນັດ',
        ],
        'YDD' => [
            'YDD',
            'ດີນາ ເຢເມນ',
        ],
        'YER' => [
            'YER',
            'ເຢ​ເມ​ນິ ຣຽວ',
        ],
        'YUD' => [
            'YUD',
            'ຮາດດີນາ ຢູໂກສະລາວີ',
        ],
        'YUM' => [
            'YUM',
            'ດີນາໃໝ່ ຢູໂກສະລາວີ (1994–2002)',
        ],
        'YUN' => [
            'YUN',
            'ດີນາ ທີ່ປ່ຽນສະພາບ ຢູໂກສະລາວີ (1990–1992)',
        ],
        'YUR' => [
            'YUR',
            'ດີນາ ປະຕິຮູບ ຢູໂກສະລາວີ (1992–1993)',
        ],
        'ZAL' => [
            'ZAL',
            'ແຣນ ອາຟຣິກາໃຕ້ (ການເງິນ)',
        ],
        'ZAR' => [
            'ZAR',
            'ເຊົາທ໌ ອາ​ຟຣິ​ກັນ ແຣນດ໌',
        ],
        'ZMK' => [
            'ZMK',
            'ຄວາຊາ ຊັມເບຍ (1968–2012)',
        ],
        'ZMW' => [
            'ZMW',
            'ແຊມ​ບຽນ ຄວາ​ຊາ',
        ],
        'ZRN' => [
            'ZRN',
            'ແຊ ຄອງໂກໃໝ່',
        ],
        'ZRZ' => [
            'ZRZ',
            'ແຊຄອງໂກ',
        ],
        'ZWD' => [
            'ZWD',
            'ດອນລາ ຊິມບັບເວ (1980–2008)',
        ],
        'ZWG' => [
            'ZWG',
            'ຊິມບັບວຽນ ໂກລ',
        ],
        'ZWL' => [
            'ZWL',
            'ດອນລາ ຊິມບັບເວ (2009)',
        ],
        'ZWR' => [
            'ZWR',
            'ດອນລາ ຊິມບັບເວ (2008)',
        ],
    ],
];
